AstroPhot API Reference
=======================

This reference documents all public classes and functions in AstroPhot.
Use the module index below to navigate to specific components.

.. toctree::
   :maxdepth: 2

   models
   image
   fit
   plots
   utils
   errors
